@@ -65,7 +65,7 @@ def simple_gen():
 
 def test_numpy_from_generator(tmp_path):
     memmap = np_ninja.from_generator(
-        out_dir=tmp_path / "generator", sample_generator=simple_gen(), n=30, batch_size=4, verbose=True
+        out_dir=tmp_path / "generator", sample_generator=simple_gen(), batch_size=4, verbose=True
     )
     memmap = np_ninja.open_existing(tmp_path / "generator")
     for i in range(30):
@@ -73,15 +73,15 @@ def test_numpy_from_generator(tmp_path):
 
 
 def test_read_only(tmp_path):
-    out_path = tmp_path / 'read_only_numpy_memmap'
+    out_path = tmp_path / "read_only_numpy_memmap"
     arr = np.arange(10)
     np_ninja.from_ndarray(out_path, arr)
     # Make all memmap files read-only for the user
-    for p in out_path.glob(r'**/*'):
+    for p in out_path.glob(r"**/*"):
         if not p.is_file():
             continue
         os.chmod(p, stat.S_IRUSR)
     # Open in read-only mode
-    memmap = np_ninja.open_existing(out_path, mode='r')
+    memmap = np_ninja.open_existing(out_path, mode="r")
     for i, el in enumerate(arr):
         assert el == memmap[i]
